/***********************************************************
 * XMMS InfoPipe plugin: UI functions
 * Distributed under GNU GPL. See the COPYING file for details.
 *
 * Written by Weyfour WWWWolf (Urpo Lankinen),
 * 2001-01-11 and onward
 *
 * $Id: infopipe_ui.c,v 1.4 2002/03/06 13:23:56 wwwwolf Exp $
 *
 ***********************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <xmms/plugin.h>
#include <xmms/util.h>

#include "../config.h"
#include "infopipe.h"

/*
  Shows an about box.
 */
void show_about(void) {
  char *stuff = (char *)malloc(4096*sizeof(char));

  strcpy(stuff, "XMMS InfoPipe\n\n");
  strcat(stuff, "Descriptive fun for the trivia-crazed and\n");
  strcat(stuff, "exhibitionists alike!\n\n");
  strcat(stuff, "Version ");
  strcat(stuff, VERSION);
  strcat(stuff, "\nby Weyfour WWWWolf (aka Urpo Lankinen)\n");
  strcat(stuff, "\n<wwwwolf@iki.fi>\n");
  strcat(stuff, "http://www.iki.fi/wwwwolf/\n");
  strcat(stuff, "\nSee README for more information.\n");


  xmms_show_message("About InfoPipe",
		    stuff,
		    "OK", FALSE, NULL, NULL);
  free(stuff);
}

/*
  Shows a configuration dialog. This is currently unimplemented...
 */
void show_config(void) {
}
